<?php
/*
Plugin Name: Dell Rev
Plugin URI: https://www.votechnolabs.com/themes-plugins/dev-rev
Description: Dell Rev Revision is based on the latest version of Wordpress (3.x) with improved
features. It not only deletes redundant revisions of posts from your Wordpress
Database, it also deletes other database content related to each revision such
meta information, tags, relationships, and more. Your current published,
scheduled, and draft posts are never touched by this plugin! This plugin can
also perform optimizations on your Wordpress database. With optimization and old
revision removal this plugin will keep your database lighter and smaller
throughout use. Removing old revisions and database optimizations is one of the
best things you can do to your Wordpress blog to keep it running as fast as it
can.
Author: Balkrushn
Version: 1.0
Author URI: https://www.votechnolabs.com/
License: votechnolabs
*/

/*
	THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY
	KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
	WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
	PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS
	OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR
	OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
	OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
	SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
*/

/*
* Function to display admin menu.
*/
if ( ! function_exists( 'dell_rev_admin_menu' ) ) {
	function dell_rev_admin_menu() {
		add_options_page( __( 'Dell Rev', 'dr' ), __( 'Dell Rev', 'dr' ), 'manage_options', basename( __FILE__ ), 'dr_page' );
	}
}

/*
* Function to add localization to the plugin.
*/
if ( ! function_exists ( 'dr_init' ) ) {
	function dr_init() {
		/* Internationalization. */
		load_plugin_textdomain( 'dr', false, dirname( plugin_basename( __FILE__ ) ) . '/languages/' );

		if ( isset( $_GET['page'] ) && $_GET['page'] == 'dell-rev.php' ) {
			dr_default_options();
		}
	}
}

/*
* Function to add script and styles to the admin panel.
*/
if ( ! function_exists( 'rev_admin_head' ) ) {
	function rev_admin_head() {
		wp_enqueue_style( 'dr_stylesheet', plugins_url( 'css/style.css', __FILE__ ) );
	}
}
/*
* Function to set up options.
*/
if ( ! function_exists( 'dr_default_options' ) ) {
	function dr_default_options() {
		global $wpmu, $dell_rev_no;
		if ( $wpmu == 1 ) {
			if ( ! get_site_option( 'dell_rev_no' ) ) {
				add_site_option( 'dell_rev_no', 0, '', 'yes' );
			}
			$dell_rev_no = get_site_option( 'dell_rev_no' );
		} else {
			if ( ! get_option( 'dell_rev_no' ) ) {
				add_option( 'dell_rev_no', 0, '', 'yes' );
			}
			$dell_rev_no = get_option( 'dell_rev_no' );
		}
	}
}

/*
* Function to display plugin main settings page.
*/
if ( ! function_exists( 'dr_page' ) ) {
	function dr_page() {
		global $wpdb, $dell_rev_no;

		$dell_plugin_info = get_plugin_data( __FILE__ );
		$dr_version = $dell_plugin_info['Version'];
		$dell_posts = count(
			$wpdb->get_results(
				"SELECT ID
				FROM ($wpdb->posts)
				WHERE `post_type` = 'post'"
			)
		); ?>
		<div class="wrap">
			<h2><?php _e( 'Dell Rev Manager', 'dr' ); ?> <font size=1><?php echo $dr_version; ?></font></h2>
			<div class="dell_widget">
				<p><?php _e( 'You have', 'dellrev' ); ?> <span><?php echo $dell_posts; ?></span> <?php _e( 'posts', 'dr' ); ?>.</p>
				<p><?php _e( 'Since you started using Dell Rev', 'dr' ); ?>, <span id="dell_rev_no"><?php echo $dell_rev_no; ?></span> <?php _e( 'redundant post revisions have been removed!', 'dr' ); ?></p>
			</div><!-- .widget -->
			<?php if ( isset( $_POST['dell_get_rev'] ) && check_admin_referer( plugin_basename( __FILE__ ) ) ) {
				$dell_result = $wpdb->get_results(
					"SELECT `ID`,`post_date`,`post_title`,`post_modified`
					FROM ($wpdb->posts)
					WHERE `post_type` = 'revision'
					ORDER BY `ID` DESC"
				);
				if ( $dell_result ) {
					$dell_res_no = count( $dell_result ); ?>
					<table class="widefat dr_table">
						<thead>
							<tr>
								<th width="30"><?php _e( 'Id', 'dr' ); ?></th>
								<th width="450"><?php _e( 'Title', 'dr' ); ?></th>
								<th width="180"><?php _e( 'Post date', 'dr' ); ?></th>
								<th width="180"><?php _e( 'Last modified', 'dr' ); ?></th>
							</tr>
						</thead>
						<tbody>
							<?php for ( $i = 0 ; $i < $dell_res_no ; $i++ ) { ?>
								<tr>
									<td><?php echo $dell_result[ $i ]->ID; ?></td>
									<td><?php echo $dell_result[ $i ]->post_title; ?></td>
									<td><?php echo $dell_result[ $i ]->post_date; ?></td>
									<td><?php echo $dell_result[ $i ]->post_modified; ?></td>
								</tr>
							<?php } ?>
						</tbody>
					</table>
					<p><?php _e( 'Would you like to remove the revision posts?', 'dr' )?></p>
					<form class="dell_form" method="post" action="options-general.php?page=dell-rev.php">
						<?php wp_nonce_field( plugin_basename( __FILE__ ) ); ?>
						<input type="hidden" name="dell_rev_no" value="<?php echo $dell_res_no; ?>" />
						<input class="button-primary" type="submit" name="dr_del_act" value="<?php printf( __( 'Yes , I would like to delete them! (A Total Of %s)' , 'dr' ), $dell_res_no ); ?>" />
						<input class="button" type="submit" name="goback" value="<?php _e( 'No , I prefer to keep them!', 'dr' ); ?>" />
					</form>
				<?php } else { ?>
					<div class="updated dell_no_rev">
						<p>
							<?php _e( 'Great! You have no revisions now!', 'dr' ); ?>
						</p>
					</div>
				<?php }
			} elseif ( isset( $_POST['dr_del_act'] ) && check_admin_referer( plugin_basename( __FILE__ ) ) ) {
				$dr_ngg_fix = dr_get_ngg_fix();
				$dr_revisions = $wpdb->get_results(
					"SELECT `ID` AS revision_id
					FROM ($wpdb->posts)
					WHERE `post_type` = 'revision'
					ORDER BY `ID` DESC"
				);
				if ( is_array( $dr_ngg_fix ) ) {
					remove_action( $dr_ngg_fix['tag'], array( $dr_ngg_fix['class'], $dr_ngg_fix['method'] ), $dr_ngg_fix['priority'] );
				}
				foreach ( $dr_revisions as $dr_revision ) {
					echo $dr_revision->revision_id;
					wp_delete_post_revision( $dr_revision->revision_id );
				}
				if ( is_array( $dr_ngg_fix ) ) {
					add_action( $dr_ngg_fix['tag'], array( $dr_ngg_fix['class'], $dr_ngg_fix['method'] ), $dr_ngg_fix['priority'] );
				}
				$dr_del_no = $_POST['dell_rev_no'];
				$dr_rev_new = $dell_rev_no + $dr_del_no;
				update_option( 'dell_rev_no', $dr_rev_new ); ?>
				<div class="updated dell_updated">
					<p>
						<strong><?php printf( __( 'Deleted %s revisions!', 'dr' ), sprintf( '<span>%s</span>', $dr_del_no ) ); ?></strong>
					</p>
				</div>
				<script type="text/javascript">
					document.getElementById( 'dr_revs_no' ).innerHTML = <?php echo $dr_rev_new; ?>;
				</script>
			<?php } elseif ( isset( $_POST['dr_maintain_mysql'] ) && check_admin_referer( plugin_basename( __FILE__ ) ) ) {
				if ( isset( $_POST['dr_operation'] ) && $_POST['dr_operation'] == 'OPTIMIZE' ) {
					$dr_operation = 'OPTIMIZE';
				} else {
					$dr_operation = 'CHECK';
				}

				$dr_tables = $wpdb->get_results( 'SHOW TABLES IN ' . DB_NAME );
				$dr_query = "$dr_operation TABLE";
				$dr_tables_in_db_name = 'Tables_in_' . DB_NAME;

				foreach ( $dr_tables as $k => $v ) {
					$dr_table = $v->$dr_tables_in_db_name;
					$dr_query .= " `$dr_table`,";
				}
				$dr_query = substr( $dr_query, 0, strlen( $dr_query ) - 1 );
				$dr_result = $wpdb->get_results( $dr_query );

				switch ( $dr_operation ) {
					case 'OPTIMIZE': ?>
						<h3><?php _e( 'Optimization of database completed!', 'dr' ); ?></h3>
						<?php break;
					case 'CHECK':
					default: ?>
						<table border="0" class="widefat dr_table">
							<thead>
								<tr>
									<th><?php _e( 'Table', 'dr' ); ?></th>
									<th><?php _e( 'OP', 'dr' ); ?></th>
									<th><?php _e( 'Status', 'dr' ); ?></th>
								</tr>
							</thead>
							<tbody>
								<?php foreach ( $dr_result as $j => $o ) { ?>
									<tr>
										<?php foreach ( $o as $k => $v ) {
											$dr_tr_class = $j%2 == 1 ? 'active alt' : 'inactive';
											if ( $k == 'Msg_type' ) {
												continue;
											}
											if ( $k == 'Msg_text' ) {
												if ( $v == 'OK' ) { ?>
													<td class="<?php echo $dr_tr_class; ?>">
														<font color="green">
															<b><?php echo $v; ?></b>
														</font>
													</td>
												<?php } else { ?>
													<td class="<?php echo $dr_tr_class; ?>">
														<font color="red">
															<b><?php echo $v; ?></b>
														</font>
													</td>
												<?php }
											} else { ?>
												<td class="<?php echo $dr_tr_class; ?>">
													<?php echo $v; ?>
												</td>
											<?php }
										} ?>
									</tr>
								<?php } ?>
							</tbody>
							<tfoot>
								<tr>
									<th colspan="3">
										<?php printf(
											__( 'If all statuses are %s, then your database does not need any optimization! If any are %s, then click on the following button to optimize your Wordpress database.', 'dr' ),
											sprintf( '<font color="green">%s</font>', __( 'OK', 'dr' ) ),
											sprintf( '<font color="red">%s</font>', __( 'red', 'dr' ) )
										); ?>
									</th>
								</tr>
							</tfoot>
						</table>
						<form class="dell_form" method="post" action="options-general.php?page=dell-rev.php">
							<?php wp_nonce_field( plugin_basename( __FILE__ ) ); ?>
							<input name="dr_operation" type="hidden" value="OPTIMIZE" />
							<input name="dr_maintain_mysql" type="hidden" value="OPTIMIZE" />
							<input name="submit" type="submit" class="button-primary" value="<?php _e( 'Optimize Wordpress Database', 'dr' ); ?>" />
						</form>
						<?php break;
				}
			} else { ?>
				<form class="dell_form" method="post" action="options-general.php?page=dell-rev.php">
					<?php wp_nonce_field( plugin_basename( __FILE__ ) ); ?>
					<input class="button" type="submit" name="dell_get_rev" value="<?php _e( 'Check Revision Posts', 'dr' ); ?>" />
					<input class="button" type="submit" name="dr_maintain_mysql" value="<?php _e( 'Optimize Your Database', 'dr' ); ?>" />
				</form>
			<?php } ?>
			<div class="dell_widget">
				<p>
					<?php _e( 'Post Revisions are a feature introduced in Wordpress 2.6. Whenever you or Wordpress saves a post or a page, a revision is automatically created and stored in your Wordpress database. Each additional revision will slowly increase the size of your database. If you save a post or page multiple times, your number of revisions will greatly increase overtime. For example, if you have 100 posts and each post has 10 revisions you could be storing up to 1,000 copies of older data!', 'dr' ); ?>
				</p>
				<br />
				<p>
					<?php _e( 'Thank you for using this plugin! I hope you enjoy it!', 'dr' ); ?>
				</p>
				<br />
				<p><?php _e( 'Author:', 'dr' ); ?> <a href="https://www.votechnolabs.com" target="_blank">www.votechnolabs.com</a></p>
			</div>
		</div><!-- .wrap -->
	<?php }
}

/*
* Fix for plugin NextGEN Gallery.
*/
if ( ! function_exists( 'dr_get_ngg_fix' ) ) {
	function dr_get_ngg_fix() {
		global $wp_filter;
		if ( ! function_exists( 'get_plugins' ) ) {
			require_once ABSPATH . 'wp-admin/includes/plugin.php';
		}
		$dr_is_ngg_active = is_plugin_active( 'nextgen-gallery/nggallery.php' );
		$dr_class = 'M_Attach_To_Post';
		if ( $dr_is_ngg_active && class_exists( $dr_class ) ) {
			$dr_tag = 'after_delete_post';
			$dr_method = 'cleanup_displayed_galleries';
			$dr_filters = $wp_filter[ $dr_tag ];
			if ( ! empty( $dr_filters ) ) {
				foreach ( $dr_filters as $dr_priority => $dr_filter ) {
					foreach ( $dr_filter as $dr_identifier => $dr_function ) {
						if ( is_array( $dr_function) AND is_a( $dr_function['function'][0], $dr_class ) AND $dr_method === $dr_function['function'][1] ) {
							return array(
								'tag'      => $dr_tag,
								'class'    => $dr_function['function'][0],
								'method'   => $dr_method,
								'priority' => $dr_priority
							);
						}
					}
				}
			}
		}
		return false;
	}
}

/*
* Adds Settings link to the plugins page
*/
if ( ! function_exists( 'dr_plugin_action_links' ) ) {
	function dr_plugin_action_links( $links, $file ) {
		/* Static so we don't call plugin_basename on every plugin row. */
		static $this_plugin;
		if ( ! $this_plugin )
			$this_plugin = plugin_basename( __FILE__ );
		if ( $file == $this_plugin ) {
			$settings_link = '<a href="options-general.php?page=dell-rev.php">' . __( 'Settings', 'dr' ) . '</a>';
			array_unshift( $links, $settings_link );
		}
		return $links;
	}
}

/*
* Adds additional links to the plugins page
*/
if ( ! function_exists( 'dr_links' ) ) {
	function dr_links( $links, $file ) {
		/* Static so we don't call plugin_basename on every plugin row. */
		static $base;
		if ( ! $base )
			$base = plugin_basename( __FILE__ );
		if ( $file == $base ) {
			$links[] = '<a href="options-general.php?page=dell-rev.php">' . __( 'Settings','dr' ) . '</a>';
			$links[] = '<a href="http://wordpress.org/plugins/better-delete-revision/faq" target="_blank">' . __( 'FAQ','dr' ) . '</a>';
		}
		return $links;
	}
}

/*
* Function to uninstall plugin.
*/
if ( ! function_exists( 'dr_uninstall' ) ) {
	function dr_uninstall() {
		delete_option( 'dell_rev_no' );
		delete_site_option( 'dell_rev_no' );
	}
}

/* Displaying admin menu */
add_action( 'admin_menu', 'dell_rev_admin_menu' );
/* Initialization */
add_action( 'init', 'dr_init' );
/* Adding styles in the admin panel */
add_action( 'admin_enqueue_scripts', 'rev_admin_head' );
/* Adds additional links to the plugins page */
add_filter( 'plugin_action_links', 'dr_plugin_action_links', 10, 2 );
add_filter( 'plugin_row_meta', 'dr_links', 10, 2 );
/* Uninstall plugin */
register_uninstall_hook( __FILE__, 'dr_uninstall' );